@@ -1,25 +1,12 @@
 /*
   This file is part of the kcalutils library.
 
-  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-  Copyright (c) 2001,2002,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 1998 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2001, 2002, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 /**
   @file
@@ -35,10 +22,10 @@
 
 #include "kcalutils_export.h"
 
-#include <kcalendarcore/event.h>
-#include <kcalendarcore/journal.h>
-#include <kcalendarcore/todo.h>
-#include <kcalendarcore/memorycalendar.h>
+#include <KCalendarCore/Event>
+#include <KCalendarCore/Journal>
+#include <KCalendarCore/Todo>
+#include <KCalendarCore/MemoryCalendar>
 
 #include <QDateTime>
 
