@@ -1,30 +1,17 @@
 /*
   This file is part of the kcalutils library.
 
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "htmlexport.h"
 #include "htmlexportsettings.h"
 #include "stringify.h"
 #include "incidenceformatter.h"
 
-#include <kcalendarcore/memorycalendar.h>
+#include <KCalendarCore/MemoryCalendar>
 using namespace KCalendarCore;
 
 #include "kcalutils_debug.h"
@@ -229,11 +216,11 @@ void HtmlExport::createMonthView(QTextStream *ts)
                     Event::List events = d->mCalendar->events(start, d->mCalendar->timeZone(),
                                                               EventSortStartDate,
                                                               SortDirectionAscending);
-                    if (events.count()) {
+                    if (!events.isEmpty()) {
                         *ts << "<table>";
                         Event::List::ConstIterator it;
-                        Event::List::ConstIterator end(events.constEnd());
-                        for (it = events.constBegin(); it != end; ++it) {
+                        Event::List::ConstIterator endEvents(events.constEnd());
+                        for (it = events.constBegin(); it != endEvents; ++it) {
                             if (checkSecrecy(*it)) {
                                 createEvent(ts, *it, start, false);
                             }
@@ -294,7 +281,7 @@ void HtmlExport::createEventList(QTextStream *ts)
         Event::List events = d->mCalendar->events(dt, d->mCalendar->timeZone(),
                                                   EventSortStartDate,
                                                   SortDirectionAscending);
-        if (events.count()) {
+        if (!events.isEmpty()) {
             *ts << "  <tr><td colspan=\"" << QString::number(columns)
                 << "\" class=\"datehead\"><i>"
                 << QLocale().toString(dt)
@@ -441,7 +428,7 @@ void HtmlExport::createTodoList(QTextStream *ts)
     for (it = todoList.constBegin(); it != todoList.constEnd(); ++it) {
         Incidence::List relations = d->mCalendar->relations((*it)->uid());
 
-        if (relations.count()) {
+        if (!relations.isEmpty()) {
             // Generate sub-to-do list
             *ts << "  <tr>" << returnEndLine();
             *ts << "    <td class=\"subhead\" colspan=";
@@ -503,7 +490,7 @@ void HtmlExport::createTodo(QTextStream *ts, const Todo::Ptr &todo)
     if (!todo->description().isEmpty()) {
         *ts << "    <p>" << breakString(cleanChars(todo->description())) << "</p>" << returnEndLine();
     }
-    if (relations.count()) {
+    if (!relations.isEmpty()) {
         *ts << "    <div align=\"right\"><a href=\"#sub" << todo->uid()
             << "\">" << i18nc("@title:column sub-to-dos of the parent to-do",
                           "Sub-To-dos") << "</a></div>" << returnEndLine();
