@@ -1,32 +1,19 @@
 /*
   This file is part of the kcalutils library.
 
-  Copyright (c) 2000-2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2000-2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef KCALUTILS_HTMLEXPORT_H
 #define KCALUTILS_HTMLEXPORT_H
 
 #include "kcalutils_export.h"
 
-#include <kcalendarcore/event.h>
-#include <kcalendarcore/incidence.h>
-#include <kcalendarcore/todo.h>
+#include <KCalendarCore/Event>
+#include <KCalendarCore/Incidence>
+#include <KCalendarCore/Todo>
 
 #include <QString>
 
